##############################################################################
#
# Copyright (c) 2002 Ingeniweb SARL
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
#
##############################################################################

"""PloneSelenium product"""
from OFS.ObjectManager import BadRequestException
from Products.CMFCore.TypesTool import ContentFactoryMetadata
from Products.CMFCore.DirectoryView import createDirectoryView, addDirectoryViews
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.TypesTool import FactoryTypeInformation as fti_klass
from Products.PloneSelenium.global_symbols import *
from Products.PloneSelenium.PloneSeleniumTool import PloneSeleniumTool
from Products.Zelenium import zelenium_globals 

def install(self):
    """ Install this product """
    out = []
    typesTool = getToolByName(self, 'portal_types')
    skinsTool = getToolByName(self, 'portal_skins')

    # add in the directory view pointing to our skin
    for layer_name, layer_location in layers:
        try:
            if layer_name not in skinsTool.objectIds():
                createDirectoryView(skinsTool, layer_location, layer_name)
                out.append('Added "%s" directory view to portal_skins' % layer_name)
        except BadRequestException, e:
            pass
            
    # add in the layer to all our skins    
    skins = skinsTool.getSkinSelections()
    for skin in skins:
        path = skinsTool.getSkinPath(skin)
        path = [ p.strip() for p in path.split(',') ]
        index = 0
        for layer_name,layer_location in layers:
            if layer_name not in path:
                index += 1
                path.insert(path.index('custom')+index, layer_name)
                out.append('Added "%s" to "%s" skins' % (layer_name, skin))
        
        path = ", ".join(path)
        skinsTool.addSkinSelection(skin, path)
        
    # Install configlet
    cptool = getToolByName(self, 'portal_controlpanel')
    try:
        cptool.unregisterConfiglet(ploneselenium_prefs_configlet['id'])
    except:
        pass
    try:
        cptool.registerConfiglet(**ploneselenium_prefs_configlet)
    except:
        pass
    out.append('Adding PloneSelenium Configlet')

    # Install tool
    add_tool = self.manage_addProduct['PloneSelenium'].manage_addTool
    selenium_tool = getattr(self, PloneSeleniumTool.id, None)
    if selenium_tool is None:
        add_tool(PloneSeleniumTool.meta_type)
    else:
        selenium_tool.initProperties()

    suites = ['PloneSelenium',
              'Workflow',
              'Content',
              'Search',
              'MailHost',
              'PrivateSite',
              'UseCase_Login',
              'UseCase_PasswordForgotten',
              'UseCase_NewUser',
              'UseCase_ChangePassword',
              'UseCase_EnableComments',
              'UseCase_PersonalPreferences',
              'UseCase_Expiration',
              'UseCase_LocalRoles',

              'Permissions',
              
              #
              # General Zope permissions
              #

              #'Permissions_AccessContentsInformation',
              #'Permissions_ChangePermissions',              
              'Permissions_DeleteObjects',
              #'Permissions_FTPAccess',
              #'Permissions_ManageProperties',
              #'Permissions_ManageUsers',
              #'Permissions_UndoChanges',              
              #'Permissions_View',              
              #'Permissions_ViewManagementScreens',
              
              
              #
              # CMF Base Permissions
              #

              'Permissions_ListFolderContents',
              #'Permissions_ListUndoableChanges',
              #'Permissions_AccessInactivePortalContent',
              #'Permissions_ModifyCookieCrumblers',
              #'Permissions_ReplyToItem',
              'Permissions_ManagePortal',
              #'Permissions_ModifyPortalContent',
              'Permissions_ListPortalMembers',
              #'Permissions_AddPortalFolders',
              'Permissions_AddPortalContent',
              #'Permissions_AddPortalMember',
              'Permissions_SetOwnPassword',
              #'Permissions_SetOwnProperties',
              #'Permissions_ChangeLocalRoles',           
              'Permissions_MailForgottenPassword',
              
              #
              # Workflow Permissions
              #
              
              'Permissions_RequestReview',
              'Permissions_ReviewPortalContent',
              'Permissions_AccessFuturePortalContent',              
              ]
              
    provider = getToolByName(self, 'portal_selenium')
    if provider:
        for suite in suites:
            # Functional Tests
            action = {'id':suite.lower(),
                      'name':suite,
                      'action':'string:here/get_%s_ftests'%suite.lower(),
                      'condition': '',
                      'permission': 'View',
                      'category':'ftests',
                      'visible': 1}
            provider.addAction(**action)
            out.append("Action '%s' added to '%s' action provider" % (str(action['id']), 'portal_selenium'))

    return "\n".join(out)

def uninstall(self):
    """ UnInstall this product """
    out = []
    typesTool = getToolByName(self, 'portal_types')
    skinsTool = getToolByName(self, 'portal_skins')
        
    # uninstall configlets
    cptool = getToolByName(self, 'portal_controlpanel')
    cptool.unregisterConfiglet(ploneselenium_prefs_configlet['id'])
    out.append('Removing PloneSelenium Configlet')

    # add in the directory view pointing to our skin
    layer_names = [name for name, location in layers]
    try:
        skinsTool.manage_delObjects(layer_names)
        out.append('Deleted "%s" directory view from portal_skins' % layer_names)
    except BadRequestException, e:
        pass  # directory view has already been deleted
         
    # add in the layer to all our skins    
    skins = skinsTool.getSkinSelections()
    for skin in skins:
        paths = skinsTool.getSkinPath(skin)
        paths = [ p.strip() for p in paths.split(',') ]
        for layer_name,layer_location in layers:
              if layer_name in paths:
                paths.pop(paths.index(layer_name))
                out.append('Removed "%s" from %s" skins' % (layer_name, skin))    
        paths = ", ".join(paths)
        skinsTool.addSkinSelection(skin, paths)

      
    return "\n".join(out)
