"""$Id: """
#######################################################################
#                                                                     #
#                  copyright (c) 2003 Ingeniweb SARL                  #
#                                                                     #
#######################################################################

"""PloneSelenium FTest Library"""

# Python imports
import os

_defaultstartdate={'years': '2005', 'months': 'June', 'days': '30',
                                'hours': '10', 'minutes': '00'}
_defaultenddate={'years': '2005', 'months': 'June', 'days': '30',
                                'hours': '20', 'minutes': '00'}

class FTestLibrary:

    def test_logout(self):
        t = self.getTest()
        t.open("/logout")
        return t

    TestLogout = test_logout # TestLogout is deprecated

    def test_login_portlet(self, login=''):
        t = self.getTest()
        t.open("/logout")
        t.type("__ac_name", login)
        t.type("__ac_password", "admin")
        t.clickAndWait("submit")
        t.verifyTextPresent(login)
        return t

    TestLoginPortlet = test_login_portlet # TestLoginPortlet is deprecated

    def test_switch_to_language(self, language='en', verify_text=''):
        t = self.getTest()
        # "Test Switch to Language"
        t.open('/')
        t.open("/index_html?set_language=%s" % language)
        if verify_text:
            t.verifyTextPresent(verify_text)
        return t

    TestSwitchToLanguage = test_switch_to_language # TestSwitchToLanguage deprecated

    def test_access_url_verify_text(self, url, text):
        t = self.getTest()
        # "Access %s and Verify Text %s" % (url, text)
        t.open(url)
        t.verifyTextPresent(text)
        return t

    TestAccessUrlVerifyText  = test_access_url_verify_text # TestLogout is deprecated

    def test_add_folder(self, folder='/', id='folder', title='folder title'):
        """Add a minimal Folder to the folder
        """       
        t = self.getTest()
        if not folder.endswith('/'):
            folder += '/'
        t.open(folder+"createObject?type_name=Folder")
        t.type("id", id)
        t.type("title", title)
        t.clickAndWait( "form_submit")
        return t

    def test_add_page(self, folder='/', id=None, title='page title', text='page text'):
        """Add a minimal Page to the folder
        """       
        t = self.getTest()
        t.open(folder)
        t.open(folder+"/createObject?type_name=Document")  # "//a[@title='A page in the portal, which can contain rich text.']")
        if id:
            t.type("id", id)
        t.type("title", title)
        t.type("text",text)
        t.clickAndWait( "form_submit")
        t.verifyTextPresent("Your changes have been saved.")
        return t

    def test_delete_object(self, folder='/', id='page'):
        """Delete an object from a folder
        """
        t = self.getTest()
        t.open("%s/folder_contents" % folder)
        t.click("//input[@id='cb_%s']" % id)
        t.clickAndWait("//input[@value='Delete']")
        t.open('%s/%s' % (folder, id))
        t.verifyTextPresent('Our apologies')
        return t

    def test_add_newsitem(self, folder='/', id='newsitem', title='news item title', text='news item text'):
        """Add a minimal News Item to the folder
        """       
        t = self.getTest()
        t.open(folder)
        if not folder.endswith('/'):
            folder += '/'
        
        t.open(folder+"createObject?type_name=News Item")
        t.type("id", id)
        t.type("title", title)
        t.type("text",text)
        t.clickAndWait( "form_submit")
        return t

    def test_add_link(self, folder='/', id='link', title='link title', url='http://localhost/'):
        """Add a minimal Link to the folder
        """       
        t = self.getTest()
        t.open(folder)
        if not folder.endswith('/'):
            folder += '/'

        t.open(folder+"createObject?type_name=Link")
        t.type("id", id)
        t.type("title", title)
        t.type("remoteUrl",url)
        t.clickAndWait( "form_submit")
        return t
        
    def test_add_event(self, folder='/', id='event', title='event title', 
            startDate=_defaultstartdate, endDate=_defaultenddate,
            eventtype='Work'):
        """Add a minimal Event to the folder
        """       
        t = self.getTest()
        t.open(folder)
        if not folder.endswith('/'):
            folder += '/'

        t.open(folder+"createObject?type_name=Event")
        t.type("id", id)
        t.type("title", title)
        t.select("edit_form_startDate_3_year",startDate['years'])
        t.select("edit_form_startDate_3_month",startDate['months'])
        t.select("edit_form_startDate_3_day",startDate['days'])
        t.select("edit_form_startDate_3_hour",startDate['hours'])
        t.select("edit_form_startDate_3_minute",startDate['minutes'])
        t.select("edit_form_endDate_4_year",endDate['years'])
        t.select("edit_form_endDate_4_month",endDate['months'])
        t.select("edit_form_endDate_4_day",endDate['days'])
        t.select("edit_form_endDate_4_hour",endDate['hours'])
        t.select("edit_form_endDate_4_minute",endDate['minutes'])
        t.select("eventType",eventtype)
        t.clickAndWait( "form_submit")
        return t

    def test_fill_AT_date_field(self, t, datestr, format="%Y/%m/%d %H:%M", fieldName="date"):
        """
        fill an archetypes dateField
        """
        import datetime, time
        
        struct = time.strptime(datestr, format)
        ts = time.mktime(struct)
        date = datetime.datetime.fromtimestamp(ts)
        t.select(fieldName+"_year", "%d" % date.year)
        t.select(fieldName+"_month", "value=%0.2d" % date.month)
        t.select(fieldName+"_day", "%d" % date.day)
        t.select(fieldName+"_hour", "%0.2d" % (int(date.hour)))
        t.select(fieldName+"_minute", "%0.2d" % (int(date.minute)/5*5))
        
