from Products.generator.i18n import translate

#
# Command Translater
#
def translate(command, target="", value=""):
    """ Translate an api call into selenese command. """
    result = "|%s|%s|%s|" % (command, target, value)
    if command == 'testComplete':
        result == "|testComplete|"
    return result

from Dispatcher import Dispatcher

class SeleniumInterpreter(Dispatcher):
    """ Performs the following:
        1) Translates python API calls into Selenese commands,
        2) Sends the command string to the command dispatcher.

    Interpreter:
         _Computer Science_: A program that translates an instruction into a 
         machine language and executes it before proceeding to the next instruction.
         (source: http://dictionary.reference.com/search?q=Interpreter)
    """

    def __init__(self, id):
        Dispatcher.__init__(self)
        self.id = id
       
    def driver(self, REQUEST=None):
        """ expose dispatcher's webDriver method to web requests """
        return self.webDriver(REQUEST)
    

    def dispatchCommand(self, command, target="", value=""):
        command_string = translate(command, target, value)        
        return self.apiDriver(command_string)

    #
    # Selenium Actions       
    #
    def open(self, url):
        """
        Opens a URL in the test frame. This accepts both relative and
        absolute URLs.
        
        examples:
        
          * open("/mypage")
          
          * open("http://localhost/")

        Note: The URL must be on the same site as Selenium due to 
        security restrictions in the browser (Cross Site Scripting).
        """
        return self.dispatchCommand("open", url)

    def click(self, elementLocator):
        """
        Clicks on a link, button, checkbox or radio button. If the click action
        causes a new page to load (like a link usually does), use
        "clickAndWait".
        
        examples:

          * click("aCheckbox")

          * clickAndWait("submitButton")

          * clickAndWait("anyLink")

        note: Selenium will always automatically click on a popup dialog
        raised by the alert() or confirm() methods. (The exception is 
        those raised during 'onload', which are not yet handled by 
        Selenium). You must use [verify|assert]Alert or 
        [verify|assert]Confirmation to tell Selenium that you expect the popup 
        dialog. You may use chooseCancelOnNextConfirmation to click 'cancel' on
         the next confirmation dialog instead of clicking 'OK'. 
        """
        return self.dispatchCommand("click", elementLocator)
        
    def clickAndWait(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("clickAndWait", elementLocator)

    def type(self, inputLocator, value):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("type", inputLocator, value)

    def typeAndWait(self, inputLocator, value):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("typeAndWait", inputLocator, value)

    def select(self, dropDownLocator, optionSpecifier):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("select",dropDownLocator, optionSpecifier)

    def selectAndWait(self, dropDownLocator, optionSpecifier):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("selectAndWait", dropDownLocator, optionSpecifier)

    def selectWindow(self, windowId):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("selectWindow", windowId)

    def goBack(self):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("goBack")

    def close(self):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("close")

    def pause(self, milliseconds):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("pause", milliseconds)

    def fireEvent(self, elementLocator, eventName):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("fireEvent", elementLocator, eventName)

    def waitForValue(self, inputLocator, value):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("waitForValue", inputLocator, value)

    def store(self, valueToStore, variableName):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("store", valueToStore, variableName)

    def storeValue(self, inputLocator, variableName):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("storeValue", inputLocator, variableName)

    def storeText(self, elementLocator, variableName):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("storeText", elementLocator, variableName)

    def storeAttribute(self, elementLocator_at_attributeName, variableName):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("storeAttribute", elementLocator_at_attributeName, variableName)

    def chooseCancelOnNextConfirmation(self):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("chooseCancelOnNextConfirmation")

    def answerOnNextPrompt(self, answerString):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("answerOnNextPrompt", answerString)

    #
    # Selenium Checks
    #

    def verifyLocation(self, relativeLocation):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyLocation", relativeLocation)

    def assertLocation(self, relativeLocation):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertLocation", relativeLocation)

    def verifyTitle(self, titlePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyTitle", titlePattern)

    def assertTitle(self, titlePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertTitle", titlePattern)

    def verifyValue(self, inputLocator, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyValue", inputLocator, valuePattern)

    def assertValue(self, inputLocator, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertValue", inputLocator, valuePattern)

    def verifySelected(self, selectLocator, optionSpecifier):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifySelected", selectLocator, optionSpecifier)

    def assertSelected(self, selectLocator, optionSpecifier):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertSelected", selectLocator, optionSpecifier)

    def verifySelectOptions(self, selectLocator, optionLabelList):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifySelectOptions", selectLocator, optionLabelList)

    def assertSelectOptions(self, selectLocator, optionLabelList):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertSelectOptions", selectLocator, optionLabelList)

    def verifyText(self, elementLocator, textPattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyText", elementLocator, textPattern)

    def assertText(self, elementLocator, textPattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertText", elementLocator, textPattern)

    def verifyAttribute(self, elementLocator_at_attributeName, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyAttribute", elementLocator_at_attributeName, valuePattern)

    def assertAttribute(self, elementLocator_at_attributeName, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertAttribute", elementLocator_at_attributeName, valuePattern)

    def verifyTextPresent(self, text):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyTextPresent", text)

    def assertTextPresent(self, text):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertTextPresent", text)

    def verifyTextNotPresent(self, text):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyTextNotPresent", text)

    def assertTextNotPresent(self, text):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertTextNotPresent", text)

    def verifyElementPresent(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyElementPresent", elementLocator)

    def assertElementPresent(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertElementPresent", elementLocator)

    def verifyElementNotPresent(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyElementNotPresent", elementLocator)
        
    def assertElementNotPresent(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertElementNotPresent", elementLocator)

    def verifyTable(self, cellAddress, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyTable", cellAddress, valuePattern)

    def assertTable(self, cellAddress, valuePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertTable", cellAddress, valuePattern)

    def verifyVisible(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyVisible", elementLocator)

    def assertVisible(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertVisible", elementLocator)

    def verifyNotVisible(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyNotVisible", elementLocator)

    def assertNotVisible(self, elementLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertNotVisible", elementLocator)
        
    def verifyEditable(self,  inputLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyEditable", inputLocator)

    def assertEditable(self, inputLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertEditable", inputLocator)

    def verifyNotEditable(self, inputLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyNotEditable", inputLocator)

    def assertNotEditable(self, inputLocator):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertNotEditable", inputLocator)

    def verifyAlert(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyAlert", messagePattern)

    def assertAlert(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertAlert", messagePattern)

    def verifyConfirmation(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyConfirmation", messagePattern)
        
    def assertConfirmation(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertConfirmation", messagePattern)

    def verifyPrompt(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("verifyPrompt", messagePattern)
        
    def assertPrompt(self, messagePattern):
        """
        XXX Add doc from http://selenium.thoughtworks.com/seleniumReference.html
        """
        return self.dispatchCommand("assertPrompt", messagePattern)

    #
    # Selenium Misc / Undocumented
    #

    def setTextField(self, field, value):
        """
        XXX Undocumented
        """
        return self.dispatchCommand("setTextField", field, value)        
        
    def testComplete(self):
        """
        XXX Undocumented
        """
        return self.dispatchCommand("testComplete")

    def assertFailureOnNext(self, element):
        """
        XXX Undocumented
        """
        return self.dispatchCommand("assertFailureOnNext")

    def assertErrorOnNext(self, element):
        """
        XXX Undocumented
        """
        return self.dispatchCommand("assertErrorOnNext")

class PloneSeleniumInterpreter(SeleniumInterpreter):
        
    def verifyTextPresent(self, text, msgid=None, domain='plone'):
        if msgid:
            from Products.PlacelessTranslationService import translate
            text = translate(domain, 
                                          msgid, 
                                          target_language=self.language,
                                          default=text)
        return SeleniumInterpreter.verifyTextPresent(self, text) 
