## Script (Python) "get_content_ftests"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

# The following users have to exist:
#
#  sampleadmin          Manager
#  samplemember         Member

selenium = context.portal_selenium
suite = selenium.getSuite()
suite.setTargetLanguage('en')

selenium.addUser(id = 'sampleadmin',fullname='Sample Admin',roles=['Member', 'Manager',])
selenium.addUser(id = 'sampleowner',fullname='Sample Owner',roles=['Member','Owner'])
selenium.addUser(id = 'samplemember',fullname='Sample Member',roles=['Member'])

TestLogout = suite.TestLogout
TestLoginPortlet  = suite.TestLoginPortlet
TestSwitchToLanguage = suite.TestSwitchToLanguage

def test_edit_folder(folder="/folder"):
    """Edit Test Folder"""
    t = suite.getTest()
    t.open(folder)
    t.open(folder + "/edit")
    t.type("title", "An edited Folder")
    t.type("description", "Test Folder")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("An edited Folder")
    return t

def test_access_folder(folder="/folder"):
    """Access Test Folder"""
    t = suite.getTest()
    t.open(folder)
    t.verifyTextPresent("Test")
    return t

def test_edit_page(folder="/folder",id="page"):
    """Edit a Page in the Test Folder"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.open(folder + "/edit")
    t.type("title", "An edited Page")
    t.type("description", "Test Page changed")
    t.select("text_text_format","reStructured Text")
    t.type("text","A sample Text, enhanced")
    t.click("allowDiscussion_7")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("enhanced")
    return t

def test_access_page(folder="/folder",id="page"):
    """Access Test Page"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.verifyTextPresent("Test Page")
    return t

def test_edit_newsitem(folder="/folder",id='newsitem'):
    """"Add a News item to the Test Folder"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.open(folder + "/edit")
    t.type("title", "A changed News Item")
    t.type("description", "Test News Item after change")
    t.select("text_text_format","reStructured Text")
    t.type("text","A sample News Item, but now edited")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("but now edited")
    return t

def test_access_newsitem(folder="/folder",id="newsitem"):
    """Access Test News Item"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.verifyTextPresent("News Item")
    return t

def test_edit_event(folder="/folder",id="event"):
    """"Add an Event to the Test Folder"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.open(folder + "/edit")
    t.type("title", "An Event")
    t.type("description", "Test Event")
    t.select("edit_form_startDate_3_year","2005")
    t.select("edit_form_startDate_3_month","June")
    t.select("edit_form_startDate_3_day","30")
    t.select("edit_form_startDate_3_hour","10")
    t.select("edit_form_startDate_3_minute","00")
    t.select("edit_form_endDate_4_year","2005")
    t.select("edit_form_endDate_4_month","June")
    t.select("edit_form_endDate_4_day","30")
    t.select("edit_form_endDate_4_hour","12")
    t.select("edit_form_endDate_4_minute","00")
    t.type("location","Sprint Area")
    t.select("text_text_format","reStructured Text")
    t.type("text","PloneSelenium Sprint")
    t.type("attendees","Maik Roeder\r\nStefan H. Holek\r\nSasha Vinčić\r\n")
    t.select("eventType","Work")
    t.type("eventUrl","http://wiki.python.org/moin/PloneSeleniumSprint")
    t.type("contactName","Maik Roeder")
    t.type("contactEmail","maik@example.net")
    t.type("contactPhone","+46 0123 4567890")
    t.click("allowDiscussion_16")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("Maik Roeder")
    return t

def test_access_event(folder="/folder",id="event"):
    """Access Test Event"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.verifyTextPresent("Test Event")
    return t

def test_edit_link(folder="/folder",id="link"):
    """Edit Link to Test Folder"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.open(folder + "/edit")
    t.type("title", "A Link, but i change it")
    t.type("description", "Test Link, but i only changed the title and description")
    t.type("remoteUrl","http://wiki.python.org/moin/PloneSeleniumSprint")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("Test Link, but")
    return t

def test_access_link(folder="/folder",id="link"):
    """Access Test Link"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.verifyTextPresent("Test Link")
    return t

def test_page_missingtitle(folder="/folder",id="page2"):
    """"Add a Page to the Test Folder"""
    t = suite.getTest()
    t.open(folder+"/"+id)
    t.clickAndWait(folder + "/edit")
    t.type("description", "Test Page2")
    t.type("title","")
    t.select("text_text_format","reStructured Text")
    t.type("text","A sample Text")
    t.click("allowDiscussion_7")
    t.clickAndWait( "form_submit")
    t.verifyTextPresent("Please correct the indicated errors.")
    t.open(folder)
    t.verifyTextNotPresent("Test Page2")
    return t

    
suite.addTests('Add and Edit Content (Owner)',
          'Add and Edit Test Folder',
          TestLogout(),
          TestSwitchToLanguage('en'),
          TestLoginPortlet('sampleowner'),
          suite.open("/folder_delete?ids:list=folder"),
          suite.test_add_folder(folder="/",id="folder"),
          test_edit_folder(folder="/folder"),
          test_access_folder(folder="/folder"),
          'Add and edit Test Page',
          suite.open("/folder/folder_delete?ids:list=page"),
          suite.test_add_page(folder="/folder",id="page"),
          test_edit_page(folder="/folder",id="page"),
          test_access_page(folder="/folder"),
          'Add and edit Test News',
          suite.open("/folder/folder_delete?ids:list=newsitem"),
          suite.test_add_newsitem(folder="/folder",id="newsitem"),
          test_edit_newsitem(folder="/folder",id="newsitem"),
          test_access_newsitem(folder="/folder"),
          'Add and edit Test Event',
          suite.open("/folder/folder_delete?ids:list=event"),
          suite.test_add_event(folder="/folder",id="event"),
          test_edit_event(folder="/folder",id="event"),
          test_access_event(folder="/folder"),
          'Add and edit Test Link',
          suite.open("/folder/folder_delete?ids:list=link"),
          suite.test_add_link(folder="/folder",id="link"),
          test_edit_link(folder="/folder",id="link"),
          test_access_link(folder="/folder"),
          'Add Page without Title',
          suite.open("/folder/folder_delete?ids:list=page2"),
          suite.test_add_page(folder="/folder",id="page2"),
          test_page_missingtitle(folder="/folder",id="page2"),
          'Kill off the folder again',
          suite.test_delete_object(folder='/',id='folder'),
          )
suite.addTests('Add and Edit Content (Member)',
          'Add and Edit Test Folder',
          TestLogout(),
          TestSwitchToLanguage('en'),
          TestLoginPortlet('samplemember'),
          suite.open("/Members/samplemember/folder_delete?ids:list=folder"),
          suite.test_add_folder(folder="/Members/samplemember/",id="folder"),
          test_edit_folder(folder="/Members/samplemember/folder"),
          test_access_folder(folder="/Members/samplemember/folder"),
          'Add and edit Test Page',
          suite.open("/Members/samplemember/folder/folder_delete?ids:list=page"),
          suite.test_add_page(folder="/Members/samplemember/folder",id="page"),
          test_edit_page(folder="/Members/samplemember/folder",id="page"),
          test_access_page(folder="/Members/samplemember/folder"),
          'Add and edit Test News',
          suite.open("/Members/samplemember/folder/folder_delete?ids:list=newsitem"),
          suite.test_add_newsitem(folder="/Members/samplemember/folder",id="newsitem"),
          test_edit_newsitem(folder="/Members/samplemember/folder",id="newsitem"),
          test_access_newsitem(folder="/Members/samplemember/folder"),
          'Add and edit Test Event',
          suite.open("/Members/samplemember/folder/folder_delete?ids:list=event"),
          suite.test_add_event(folder="/Members/samplemember/folder",id="event"),
          test_edit_event(folder="/Members/samplemember/folder",id="event"),
          test_access_event(folder="/Members/samplemember/folder"),
          'Add and edit Test Link',
          suite.open("/Members/samplemember/folder/folder_delete?ids:list=link"),
          suite.test_add_link(folder="/Members/samplemember/folder",id="link"),
          test_edit_link(folder="/Members/samplemember/folder",id="link"),
          test_access_link(folder="/Members/samplemember/folder"),
          'Add Page without Title',
          suite.open("/Members/samplemember/folder/folder_delete?ids:list=page2"),
          suite.test_add_page(folder="/Members/samplemember/folder",id="page2"),
          test_page_missingtitle(folder="/Members/samplemember/folder",id="page2"),
          'Kill off the folder again',
          suite.test_delete_object(folder='/Members/samplemember',id='folder'),
          )

return suite
