## Script (Python) "get_mailhost_ftests"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=get_mailhost_ftests
##
selenium = context.portal_selenium
suite = selenium.getSuite()
target_language='en'
suite.setTargetLanguage(target_language)

selenium.addUser(id = 'sampleadmin',fullname='Sample Admin',roles=['Member', 'Manager',])
selenium.addUser(id = 'samplemember',fullname='Sample Member',roles=['Member'])

test_logout = suite.TestLogout()
test_admin_login  = suite.TestLoginPortlet('sampleadmin')
test_member_login  = suite.TestLoginPortlet('samplemember')

def test_configure_default_mailhost_settings():
    """Set the MailHost settings in the Control Panel to default values
    """
    t = suite.getTest()
    t.open("/plone_control_panel")
    t.verifyTextPresent('Plone Configuration')
    t.open('/prefs_mailhost_form')
    t.verifyTextPresent('Mail Setup')
    t.type('smtp_server','localhost')
    t.type('smtp_port','25')
    t.type('smtp_userid','')
    t.type('smtp_pass','')
    t.clickAndWait('form.button.Save')
    t.verifyTextPresent('Mail Host Updated')
    return t

def test_configure_invalid_mailhost_settings():
    """Change the MailHost settings in the Control Panel
    """
    t = suite.getTest()
    t.open("/plone_control_panel")
    t.verifyTextPresent('Plone Configuration')
    t.open('/prefs_mailhost_form')
    t.verifyTextPresent('Mail Setup')
    t.type('smtp_server','127.0.0.1')
    t.type('smtp_userid','user')
    t.type('smtp_pass','pass')
    t.clickAndWait('form.button.Save')
    t.verifyTextPresent('Mail Host Updated')
    return t

def test_delete_mailhost_settings():
    """Try to delete the MailHost settings in the Control Panel
    """
    t = suite.getTest()
    t.open('/prefs_mailhost_form')
    t.verifyTextPresent('Mail Setup')
    t.type('smtp_server','')
    t.type('smtp_userid','')
    t.type('smtp_pass','')
    t.clickAndWait('form.button.Save')
    t.verifyTextPresent('Mail Host Updated')
    return t

def test_send_mail_to_somebody(path='/'):
    """Try to send mail"""
    t = suite.getTest()
    t.open('/sendto_form')
    t.type('send_to_address','sampleadmin@example.net')
    t.type('send_from_address','sampleadmin@example.com')
    t.type('comment','You have to look at this')
    t.clickAndWait('form.button.Send')
    return t
    
def test_send_password(userid='samplemember'):
    """send the password to the user"""
    t = suite.getTest()
    t.open('/mail_password_form'),
    t.type('userid',userid),
    t.clickAndWait('//input[@value="Send me my password"]')
    return t

    
suite.addTests("MailHost",
          'Login as Admin',
          test_admin_login,
          suite.open(''),
          'Reset Mailhost default settings',
          test_configure_default_mailhost_settings(),
          'Use "Send this page to somebody" to test email sending.',
          test_send_mail_to_somebody(),
          suite.verifyTextPresent("Mail sent"),
          'Configure invalid MailHost Settings',
          test_configure_invalid_mailhost_settings(),          
          'Use "Send this page to somebody" to test email sending.',
          test_send_mail_to_somebody(),
          suite.verifyTextNotPresent("Mail sent"),
          'Delete Mailhost settings',
          test_delete_mailhost_settings(),
          'Use "Send this page to somebody" to test email sending.',
          test_send_mail_to_somebody(),
          suite.verifyTextNotPresent("Mail sent"),
          'Reset Mailhost default settings',         
          test_configure_default_mailhost_settings(),
          'Use "Send this page to somebody" to test email sending.',
          test_send_mail_to_somebody(),
          suite.verifyTextPresent("Mail sent")
         )
         
suite.addTests('Sending as Member',
        'Login as Member',
         test_member_login,
         suite.open(''),
         'Send this page to somebody from admin member folder',
         test_send_mail_to_somebody('/Members/sampleadmin'),
         suite.verifyTextPresent("Mail sent"),         
         'Send this page to somebody from my member folder',
         test_send_mail_to_somebody('/Members/samplemember'),
         suite.verifyTextPresent("Mail sent"),         
        )
        
suite.addTests('Sending the Password',
         'Logout',
          test_logout,
          'Send the password',
          test_send_password(userid='samplemember'),
          suite.verifyTextPresent('Password sent'),
          test_send_password(userid='samplenonmember'),
          suite.verifyTextNotPresent('Password sent')
        )        
return suite
