## Script (Python) "get_manageportal_ftests"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title="Plone manageportal permissions tests"


# "Manage Portal" permission
# The following are all uses of this permission in Plone when you search
# the source code for "Manage portal"

""""
Functional Tests:

Full text search for non-listed members in
   -  MemberDataTool.py
   -> Revealed bug #4241 (http://members.plone.org/collector/4241)
      Need to put this line in MembershipTool.py:
      from Products.CMFCore.utils import _checkPermission
Remove discussion
   - "Remove This Discussion" in plone_templates/viewThreadsAtBottom.pt
Search "Role(s)" in member search form
   - member_search_form.pt
   
"Remove This Reply" in plone_content/discussionitem_view.pt
   No more existing in Plone 2.1?

"""


selenium = context.portal_selenium
suite = selenium.getSuite()
target_language = 'en'
suite.setTargetLanguage(target_language)
selenium.addUser(id='sampleadmin',
                 fullname='Sample Admin',
                 roles=['Member', 'Manager',])
selenium.addUser(id='samplemember',
                 fullname='Sample Member',
                 roles=['Member',])

suite.addTests("Search for Members with roles",
    "Login as manager",
    suite.test_login_portlet('sampleadmin'),
    "Manager can search for Members with certain roles",
    suite.open('/Members'),
    suite.verifyTextPresent("Role(s)"),
    suite.click("//input[@value='Manager']"),
    suite.click("//input[@name='submit']"),
    "Login as member",
    suite.test_login_portlet('samplemember'),
    "Member can not search for Members with certain roles",
    suite.open('/Members'),
    suite.verifyTextNotPresent("Role(s)"),
    )

def test_allow_discussion():
    """Allow comments on the current page"""
    t = suite.getTest()
    t.clickAndWait("//li[@id='contentview-edit']//a")
    t.verifyElementPresent("//div[@class='formControls']")
    t.verifyElementPresent("//input[@name='allowDiscussion']")
    t.verifyElementPresent("//input[@value='1']")
    t.click("//input[@id='allowDiscussion_8']") # We need an id like "allowDiscussion_on"
    t.click("//input[@name='form_submit']")
    return t

def test_add_comment():
    t = suite.getTest()
    t.clickAndWait("//li[@id='contentview-view']//a")
    t.verifyElementPresent("//input[@value='Add Comment']")
    t.clickAndWait("//input[@value='Add Comment']")
    t.type('subject','My comment subject')
    t.type('body_text','My comment body text')
    t.clickAndWait("discussion_reply:method")
    return t

suite.addTests("Remove discussions",
    "Login as manager",
    suite.test_login_portlet('sampleadmin'),               
    "Allow discussion on home page",
    suite.open('/'),
    test_allow_discussion(),               
    "Add a comment",
    test_add_comment(),
    "Login as member",               
    suite.test_login_portlet('samplemember'),
    "Member can not delete the comment",
    suite.open('/'),
    suite.verifyElementNotPresent("document.forms['delete']"), # Should have id="delete_comment_form"               
    "Login as manager",
    suite.test_login_portlet('sampleadmin'),
    "Delete the comment",
    suite.open('/'),
    suite.verifyElementPresent("document.forms['delete']"), # Should have id="delete_comment_form"
    suite.clickAndWait("//input[@value='Remove']"),         # Should have id="remove_comment_button"
    suite.verifyTextPresent("Reply deleted"),               # Should use the msgid
    )

suite.addTests("Search for listed and non-listed members",
    "Login as manager",
    suite.test_login_portlet('sampleadmin'),               
    "Manager can search listed member",
    suite.open('/Members'),
    suite.type('name','samplemember'),
    suite.clickAndWait("//input[@tabindex='9']"), # Need an id
    suite.verifyTextPresent("1 items matching your criteria."),
    "Unlist member",
    suite.open('/portal_memberdata/prefs_user_details?userid=samplemember'),
    suite.click('cb_listed'),
    suite.clickAndWait('prefs_user_edit:method'),
    suite.verifyTextPresent('Changes made'),    
    "Manager can search unlisted member",
    suite.open('/Members'),
    suite.type('name','samplemember'),
    suite.clickAndWait("//input[@tabindex='9']"), # Need an id
    suite.verifyTextPresent("1 items matching your criteria."),
    "Login as member",
    suite.test_login_portlet('samplemember'),               
    "Member can not search for unlisted members",
    suite.open('/Members'),
    suite.type('name','samplemember'),
    suite.clickAndWait("//input[@tabindex='5']"), # Need an id
    suite.verifyTextPresent("No results were found."),
    "Member lists himself",
    suite.open('/personalize_form'),
    suite.click('cb_listed'),
    suite.clickAndWait('form.button.Save'),
    suite.verifyTextPresent('Your personal settings have been saved.'),    
    "Member can search himself when listed",
    suite.open('/Members'),
    suite.type('name','samplemember'),
    suite.clickAndWait("//input[@tabindex='5']"), # Need an id
    suite.verifyTextPresent("1 items matching your criteria."),        
  )

suite.addTests("Site Setup",
    "Login as manager",
    suite.test_login_portlet('sampleadmin'),
    "Manager can see link to site setup",
    suite.open('/'),
    suite.verifyElementPresent("//li[@id='siteaction-plone_setup']"),
    suite.test_login_portlet('samplemember'),
    "Member can not see link to site setup",
    suite.open('/'),
    suite.verifyElementNotPresent("//li[@id='siteaction-plone_setup']"),
    )
    
    
return suite
