## Script (Python) "get_plone_workflow_ftests"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=
##

# The following users have to exist:
#
#  sampleadmin          Manager
#  samplemember         Member
#  sampleowner          Member, Owner
#  samplereviewer       Member, Reviewer

selenium = context.portal_selenium
suite = selenium.getSuite()
suite.setTargetLanguage('en')

selenium.addUser(id = 'sampleadmin',fullname='Sample Admin',roles=['Member', 'Manager',])
selenium.addUser(id = 'samplemember',fullname='Sample Member',roles=['Member',])
selenium.addUser(id = 'sampleowner',fullname='Sample Owner',roles=['Member', 'Owner',])
selenium.addUser(id = 'samplereviewer',fullname='Sample Reviewer',roles=['Member', 'Reviewer',])

TestLogout = suite.TestLogout
TestLoginPortlet  = suite.TestLoginPortlet
TestSwitchToLanguage = suite.TestSwitchToLanguage

def TestPublishTestContent():
    """Publish Test Content"""
    t = suite.getTest()
    t.open("/testfolder/testcontent")
    t.open("/testfolder/testcontent/content_status_modify?workflow_action=publish")
    return t

def TestAddTestFolders():
    """Add Private, Visible, Pending and Published Test Folder"""
    t = suite.getTest()
    t.open("/folder_delete?ids:list=test_folder_visible")
    t.open("/folder_delete?ids:list=test_folder_private")
    t.open("/folder_delete?ids:list=test_folder_published")

    t.open("/createObject?type_name=Folder&id=test_folder_private")
    t.type("title", "A private Folder")
    t.type("description", "Test Folder: private")
    t.clickAndWait( "form_submit")
    t.open("/test_folder_private/content_status_modify?workflow_action=hide")

    t.open("/createObject?type_name=Folder&id=test_folder_visible")
    t.type("title", "A visible Folder")
    t.type("description", "Test Folder: visible")
    t.clickAndWait( "form_submit")

    t.open("/createObject?type_name=Folder&id=test_folder_published")
    t.type("title", "A published Folder")
    t.type("description", "Test Folder: published")
    t.clickAndWait( "form_submit")
    t.open("/test_folder_published/content_status_modify?workflow_action=publish")
    return t

def TestAccessFolder(state):
    """Access Private Folder"""
    t = suite.getTest()
    t.open("/test_folder_%s" % state)
    t.verifyTextPresent("Test Folder: %s" % state)
    return t

def TestAnonymousView():
    """Anonymous View"""
    t = suite.getTest()
    t.open('/')
    t.verifyLocation('/')
    return t

def TestNoAccessFolder(state, anonymous=0):
    """No access to folder"""
    error_message="Insufficient Privileges"
    msgid="heading_no_privileges"
    if anonymous:
        error_message="Please log in"
        msgid="heading_sign_in"
    t = suite.getTest()
    t.open("/test_folder_%s" % state)
    t.verifyTextPresent(error_message, msgid=msgid)
    return t

suite.addTests('Security and Workflow',
          'Add Test Folders',
          TestLogout(),
          TestSwitchToLanguage('en'),
          TestLoginPortlet('sampleadmin'),
          TestAddTestFolders(),
          'Test Admin Folder Access',
          TestAccessFolder('private'),
          TestAccessFolder('visible'),
          TestAccessFolder('published'),
          'Test Owner Folder Access',
          TestLogout(),
          TestLoginPortlet('sampleowner'),
          TestAccessFolder('private'),
          TestAccessFolder('visible'),
          TestAccessFolder('published'),
          'Test Member Folder Access',
          TestLogout(),
          TestLoginPortlet('samplemember'),
          TestNoAccessFolder('private'),
          TestAccessFolder('visible'),
          TestAccessFolder('published'),
          'Test Reviewer Folder Access',
          TestLogout(),
          TestLoginPortlet('samplereviewer'),
          TestNoAccessFolder('private'),
          TestAccessFolder('visible'),
          TestAccessFolder('published'),
          'Test Anonymous Folder Access',
          TestLogout(),
          TestAnonymousView(),
          TestNoAccessFolder('private', anonymous=1),
          TestAccessFolder('visible'),
          TestAccessFolder('published'),
          'Kill off the folders again',
          TestLoginPortlet('sampleadmin'),
          suite.test_delete_object(folder='/',id='test_folder_private'),
          suite.test_delete_object(folder='/',id='test_folder_visible'),
          suite.test_delete_object(folder='/',id='test_folder_published'),
         )

return suite
